
/**
 * Introduction to java arrays.
 * 
 * Computers are VERY good at storing, searching and sorting data.
 * However, in the programs you have worked with so far,
 * each piece of data, primitive or object, required its own specific identifier.
 * If a program was working with hundreds, thousands or even millions of values,
 * assigning a unique identifier to each one would be impossibly cumbersome.
 * 
 * To solve this naming problem programming languages use data structures like arrays.
 * An array is like a list of separate data values all given the same identifier 
 * with each value assigned its own index number. 
 * 
 * You already worked with this concept when you used String methods.
 * A String is much like an array of keyboard characters (substrings).
 * A String may only have one identifier but each of the substrings it 
 * contains has its own index number that allows you to access them separately.
 * 
 * When an array is instantiated, the type of data to be stored 
 *       int[], double[], boolean[], String[] ...
 * and the length of the array must be declared.
 * 
 * See the array examples below.
 * 
 * @author GrayKnight
 * @version 11/5/12  1/6/16
 */

public class Array_Driver
{
    
    //In this example instance arrays are shown instantiated two different ways.
    
    
    //#1)  With an initialization list:
                    //indices  0   1   2   3   4   just like a String!
    private int[] myScores = {77, 95, 83, 85, 98};
    
    
    //#2)  Without an initialization list:
    //a length is required. In this example 50 indices are made and filled with zeros.
    private int[] myRandomArray = new int[50];
    
    //indices    0   1   2   3   4    ...   47  48  49
    //integers   0   0   0   0   0    ...    0   0   0  (zeros are default values)
    
    public void driver()
    {
        //The ap object will perform some operations on the arrays.
        //Reference to the myScores array is passed to the ap object as a parameter.
        Array_Processor ap = new Array_Processor(myScores);
        
        //The ap object methods return an integer and String stored here as arraySum and arrayStr.
        int arraySum = ap.sumOfArray();
        String arrayStr = ap.toString();
        System.out.println("Here is an array of test scores:\n" + arrayStr);
        System.out.println("The sum of the scores is: " + arraySum + "\n");
                     
                   //The value at the index of [20] was never assigned, however
                   // this will display 0 because java defaults numeric primitives to 0.
        System.out.println("java defaults numeric primitives to " + myRandomArray[20] + "\n");
        
        //Arrays are passed by reference. The array is NOT duplicated when it is passed.
        //Only its memory location is sent as a parameter.
        ap.randomScoreFiller(myRandomArray);//fill'er-up!
        
        //The ap object method toString is automatically called when its identifier
        // is sent to System.out.println
        System.out.println("Here is an array of random scores:\n" + ap);
        
    }

}
